@@ -25,7 +25,6 @@
 #include <QTabBar>
 #include <QToolButton>
 
-#include "core/manager.h"
 #include "core/model.h"
 #include "core/widgets/quicksearchline.h"
 #include "messagelistsettings.h"
@@ -163,7 +162,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
         d->updateTabControls();
     });
 
-    connect(this, &QTabWidget::tabBarDoubleClicked, this, &Pane::createNewTab);
+    // connect(this, &QTabWidget::tabBarDoubleClicked, this, &Pane::createNewTab);
 
     tabBar()->installEventFilter(this);
 }
